#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.analysis_interfaces.analysis_image import AnalysisImage
from pycatia.system_interfaces.collection import Collection
from pycatia.types.general import cat_variant


class ABQSolutionCaseImages(Collection):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.Collection
                |                     ABQSolutionCaseImages
                | 
                | The collection of analysis images under the solution case
    
    """

    def __init__(self, com_object):
        super().__init__(com_object, child_object=AnalysisImage)
        self.abq_solution_case_images = com_object

    def item(self, i_index: cat_variant) -> AnalysisImage:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Item(CATVariant iIndex) As AnalysisImage
                | 
                |     Returns an analysis image using its index or its name from the
                |     ABQSolutionCaseImages collection.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index or the name of the analysis image to retrieve from the
                |             collection of analysis images. If the index is a number, it specifies the rank
                |             of the analysis image in the collection. The index of the first analysis image
                |             in the collection is 1, and the index of the last image is Count. If the index
                |             is a string, it specifies the name you assigned to the image using the
                |             CATIACollection::Name property. 
                | 
                |     Returns:
                |         The specified AnalysisImage.

        :param cat_variant i_index:
        :return: AnalysisImage
        :rtype: AnalysisImage
        """
        return AnalysisImage(self.abq_solution_case_images.Item(i_index))

    def remove(self, i_index: cat_variant) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Remove(CATVariant iIndex)
                | 
                |     Removes an analysis image using its index or its name from the solution
                |     case image collection.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index or the name of the analysis image to retrieve from the
                |             collection of Abaqus solution case images. If the index is a number, it
                |             specifies the rank of the analysis image in the collection. The index of the
                |             first analysis image in the collection is 1, and the index of the last image is
                |             Count. If the index is a string, it specifies the name you assigned to the
                |             image using the CATIABase::Name property.

        :param cat_variant i_index:
        :return: None
        :rtype: None
        """
        return self.abq_solution_case_images.Remove(i_index)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'remove'
        # # vba_code = """
        # # Public Function remove(abq_solution_case_images)
        # #     Dim iIndex (2)
        # #     abq_solution_case_images.Remove iIndex
        # #     remove = iIndex
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'ABQSolutionCaseImages(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.any_object import AnyObject


class ABQProperty(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     ABQProperty
                | 
                | Represents the base interface for all Abaqus property objects.
                | Role: The ABQProperty interface manages the common attributes of any Abaqus
                | property.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.abq_property = com_object

    @property
    def type(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Type() As CATBSTR (Read Only)
                | 
                |     Returns the type of the property.
                | 
                |     Returns:
                |         The type of the property.

        :return: str
        :rtype: str
        """

        return self.abq_property.Type

    def __repr__(self):
        return f'ABQProperty(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.part_interfaces.boolean_shape import BooleanShape


class Intersect(BooleanShape):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     MecModInterfaces.Shape
                |                         PartInterfaces.BooleanShape
                |                             Intersect
                | 
                | Represents the intersect boolean operation.
                | It is performed between a body and the current shape.
                | 
                | Example
                | 
                | The following example shows how to create a new shape by intersecting two
                | existing pads Pad1 and Pad2, created in two different bodies Body1 and Body2
                | respectively, using the existing shape factory named
                | shapeFactory.
                | 
                |  ' Make Pad1 the current shape
                |  CATIA.ActiveDocument.Part.CurrentShape = Pad1
                |  ' 
                |  ' Create the intersection between Pad1 and Body2 
                |  Set NewShape      = shapeFactory.AddNewIntersect(Body2)

    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.intersect = com_object

    def __repr__(self):
        return f'Intersect(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.setting_controller import SettingController


class TypeEssObjectSettingAtt(SettingController):

    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     System.SettingController
                |                         TypeESSObjectSettingAtt
                | 
                | The interface to access a CATIATypeESSObjectSettingAtt.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.type_ess_object_setting_att = com_object

    @property
    def member_types(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property MemberTypes() As CATBSTR
                | 
                |     Returns or sets the MemberTypes parameter.
                | 
                |     Ensure consistency with the C++ interface to which the work is delegated.

        :return: str
        :rtype: str
        """

        return self.type_ess_object_setting_att.MemberTypes

    @member_types.setter
    def member_types(self, value: str):
        """
        :param str value:
        """

        self.type_ess_object_setting_att.MemberTypes = value

    @property
    def plate_types(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property PlateTypes() As CATBSTR
                | 
                |     Returns or sets the PlateTypes parameter.
                | 
                |     Ensure consistency with the C++ interface to which the work is delegated.

        :return: str
        :rtype: str
        """

        return self.type_ess_object_setting_att.PlateTypes

    @plate_types.setter
    def plate_types(self, value: str):
        """
        :param str value:
        """

        self.type_ess_object_setting_att.PlateTypes = value

    def get_member_types_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetMemberTypesInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the MemberTypes
                |     parameter.
                |     Role:Retrieves the state of the MemberTypes parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :return: bool
        :rtype: bool
        """
        return self.type_ess_object_setting_att.GetMemberTypesInfo(io_admin_level, io_locked)

    def get_plate_types_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetPlateTypesInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the PlateTypes
                |     parameter.
                |     Role:Retrieves the state of the PlateTypes parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :return: bool
        :rtype: bool
        """
        return self.type_ess_object_setting_att.GetPlateTypesInfo(io_admin_level, io_locked)

    def set_member_types_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetMemberTypesLock(boolean iLocked)
                | 
                |     Locks or unlocks the MemberTypes parameter.
                |     Role:Locks or unlocks the MemberTypes parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :return: None
        :rtype: None
        """
        return self.type_ess_object_setting_att.SetMemberTypesLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_member_types_lock'
        # # vba_code = """
        # # Public Function set_member_types_lock(type_ess_object_setting_att)
        # #     Dim iLocked (2)
        # #     type_ess_object_setting_att.SetMemberTypesLock iLocked
        # #     set_member_types_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_plate_types_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetPlateTypesLock(boolean iLocked)
                | 
                |     Locks or unlocks the PlateTypes parameter.
                |     Role:Locks or unlocks the PlateTypes parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :return: None
        :rtype: None
        """
        return self.type_ess_object_setting_att.SetPlateTypesLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_plate_types_lock'
        # # vba_code = """
        # # Public Function set_plate_types_lock(type_ess_object_setting_att)
        # #     Dim iLocked (2)
        # #     type_ess_object_setting_att.SetPlateTypesLock iLocked
        # #     set_plate_types_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'TypeEssObjectSettingAtt(name="{ self.name }")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.manufacturing_interfaces.manufacturing_activities import ManufacturingActivities
from pycatia.system_interfaces.any_object import AnyObject


class ManufacturingProcess(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     ManufacturingProcess
                | 
                | A ManufacturingProcess for a Manufacturing Document.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.manufacturing_process = com_object

    @property
    def setups(self) -> ManufacturingActivities:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Setups() As MfgActivities (Read Only)
                | 
                |     Give the List of Setups linked to a Manufacturing Process.
                | 
                |     Example:
                |         The following example returns the list of Setups SetupsList linked to
                |         the manufacturing Process CurrentProcess
                | 
                |          Set SetupsList = CurrentProcess.Setups

        :return: MfgActivities
        :rtype: MfgActivities
        """

        return ManufacturingActivities(self.manufacturing_process.Setups)

    def __repr__(self):
        return f'ManufacturingProcess(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.any_object import AnyObject


class SchListOfDoubles(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     SchListOfDoubles
                | 
                | Represents a list of DOUBLEs to be used with Schematic IDLs.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.sch_list_of_doubles = com_object

    @property
    def count(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Count() As long (Read Only)
                | 
                |     Returns the number of doubles in the list.
                | 
                |     Example:
                |         This example retrieves in NumberOfdoubles the number of doubles
                |         currently gathered in MyList.
                | 
                |          NumberOfdoubles = MyList.Count

        :return: int
        :rtype: int
        """

        return self.sch_list_of_doubles.Count

    def append(self, i_double: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Append(double iDouble)
                | 
                |     Adds a double to the end of the list.
                | 
                |     Parameters:
                | 
                |         iDouble
                |             The double to be added to the list. 
                | 
                |     Example:
                | 
                |           The following example appends an object to the list.
                |
                |          Dim MyDouble As Double
                |          MyDouble = 0.6789
                |          Dim MyList As SchListOfDoubles
                |          MyList.Append(MyDouble)

        :param float i_double:
        :return: None
        :rtype: None
        """
        return self.sch_list_of_doubles.Append(i_double)

    def item(self, i_index: int) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Item(long iIndex) As double
                | 
                |     Returns a double from its index in the list.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index of the first double in the collection is 1, and the index
                |             of the last double is Count. 
                | 
                |     Returns:
                |         the retrieved double. 
                |     Example:
                | 
                |           The following example returns in the third double in the
                |           list.
                |
                |          Dim MyDouble As double
                |          Dim MyList As SchListOfDoubles
                |          Set MyDouble = SchListOfDoubles.Item(2)

        :param int i_index:
        :return: float
        :rtype: float
        """
        return self.sch_list_of_doubles.Item(i_index)

    def remove_by_index(self, i_index: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub RemoveByIndex(long iIndex)
                | 
                |     Remove a double from the list by specifying its position in the
                |     list.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The position of the double to be removed in the list.
                |
                |     Example:
                | 
                |           The following example removes the second entry in the list. Please
                |           note that the
                |          list index starts with 1.
                |
                |          Dim MyList As SchListOfDoubles
                |          MyList.Remove(1)

        :param int i_index:
        :return: None
        :rtype: None
        """
        return self.sch_list_of_doubles.RemoveByIndex(i_index)

    def __repr__(self):
        return f'SchListOfDoubles(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.setting_controller import SettingController


class ColourEssObjectSettingAtt(SettingController):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     System.SettingController
                |                         ColorESSObjectSettingAtt
                | 
                | The interface to access a CATIAColorESSObjectSettingAtt.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.colour_ess_object_setting_att = com_object

    def get_member_colour(self, o_member_colour_r: int, o_member_colour_g: int, o_member_colour_b: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetMemberColor(long oMemberColorR,
                | long oMemberColorG,
                | long oMemberColorB)
                | 
                |     Returns or sets the MemberColor parameter.
                | 
                |     Ensure consistency with the C++ interface to which the work is delegated.

        :param int o_member_colour_r:
        :param int o_member_colour_g:
        :param int o_member_colour_b:
        :return: None
        :rtype: None
        """
        return self.colour_ess_object_setting_att.GetMemberColor(o_member_colour_r, o_member_colour_g,
                                                                 o_member_colour_b)

    def get_member_colour_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetMemberColorInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the MemberColor
                |     parameter.
                |     Role:Retrieves the state of the MemberColor parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :return: bool
        :rtype: bool
        """
        return self.colour_ess_object_setting_att.GetMemberColorInfo(io_admin_level, io_locked)

    def get_plate_colour(self, o_plate_colour_r: int, o_plate_colour_g: int, o_plate_colour_b: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetPlateColor(long oPlateColorR,
                | long oPlateColorG,
                | long oPlateColorB)
                | 
                |     Returns or sets the PlateColor parameter.
                | 
                |     Ensure consistency with the C++ interface to which the work is delegated.

        :param int o_plate_colour_r:
        :param int o_plate_colour_g:
        :param int o_plate_colour_b:
        :return: None
        :rtype: None
        """
        return self.colour_ess_object_setting_att.GetPlateColor(o_plate_colour_r, o_plate_colour_g, o_plate_colour_b)

    def get_plate_colour_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetPlateColorInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the PlateColor
                |     parameter.
                |     Role:Retrieves the state of the PlateColor parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :return: bool
        :rtype: bool
        """
        return self.colour_ess_object_setting_att.GetPlateColorInfo(io_admin_level, io_locked)

    def set_member_colour(self, i_member_colour_r: int, i_member_colour_g: int, i_member_colour_b: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetMemberColor(long iMemberColorR,
                | long iMemberColorG,
                | long iMemberColorB)

        :param int i_member_colour_r:
        :param int i_member_colour_g:
        :param int i_member_colour_b:
        :return: None
        :rtype: None
        """
        return self.colour_ess_object_setting_att.SetMemberColor(i_member_colour_r, i_member_colour_g,
                                                                 i_member_colour_b)

    def set_member_color_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetMemberColorLock(boolean iLocked)
                | 
                |     Locks or unlocks the MemberColor parameter.
                |     Role:Locks or unlocks the MemberColor parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :return: None
        :rtype: None
        """
        return self.colour_ess_object_setting_att.SetMemberColorLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_member_color_lock'
        # # vba_code = """
        # # Public Function set_member_color_lock(color_ess_object_setting_att)
        # #     Dim iLocked (2)
        # #     color_ess_object_setting_att.SetMemberColorLock iLocked
        # #     set_member_color_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_plate_colour(self, i_plate_colour_r: int, i_plate_colour_g: int, i_plate_colour_b: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetPlateColor(long iPlateColorR,
                | long iPlateColorG,
                | long iPlateColorB)

        :param int i_plate_colour_r:
        :param int i_plate_colour_g:
        :param int i_plate_colour_b:
        :return: None
        :rtype: None
        """
        return self.colour_ess_object_setting_att.SetPlateColor(i_plate_colour_r, i_plate_colour_g, i_plate_colour_b)

    def set_plate_colour_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetPlateColorLock(boolean iLocked)
                | 
                |     Locks or unlocks the PlateColor parameter.
                |     Role:Locks or unlocks the PlateColor parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :return: None
        :rtype: None
        """
        return self.colour_ess_object_setting_att.SetPlateColorLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_plate_color_lock'
        # # vba_code = """
        # # Public Function set_plate_color_lock(color_ess_object_setting_att)
        # #     Dim iLocked (2)
        # #     color_ess_object_setting_att.SetPlateColorLock iLocked
        # #     set_plate_color_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'ColourEssObjectSettingAtt(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.mec_mod_interfaces.shape import Shape


class TransformationShape(Shape):

    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     MecModInterfaces.Shape
                |                         TransformationShape
                | 
                | Represents the shapes based on a transformation of another
                | shape.
                | It is the base object for mirrors and patterns.
                | 
                | See also:
                |     Mirror, Pattern, RectPattern, CircPattern 
                | 
                | Copyright © 1999-2011, Dassault Systèmes. All rights reserved.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.transformation_shape = com_object

    def __repr__(self):
        return f'TransformationShape(name="{ self.name }")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.cat_smarteam_integ_interfaces.sti_db_item import StiDBItem
from pycatia.system_interfaces.any_object import AnyObject
from pycatia.types.general import cat_variant


class StiDBChildren(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     StiDBChildren
                | 
                | Represents all the Children of a CATIAStiDBItem.
                | 
                | For each Child, we are able to retrieve its associated CATIAStiDBItem and the
                | Link Type (between itself and its father).
                | It should be represented as the following Correspondance Table { Child Number /
                | CATIAStiDBItem / Link Type}.
                | 
                | Example:
                | 
                |       The following example presents an Assembly structure and the associated
                |       Correspondance Tables for each element.
                |
                |      +-----------+
                |      |  Product  |<-----------------+
                |      +-----------+                  |
                |         |                           |
                |         |                           |
                |         |                           |
                |         |                           |
                |         |                           |
                |         |   +-----------------+     |
                |         +-->| Reference Part  |     |Contextual Link
                |         |   +-----------------+     |
                |         |            ^              |
                |         |            |              |
                |         |            | Design Link  |
                |         |            |              |
                |         |            |              |
                |         |   +-----------------+     |
                |         +-->| Contextual Part |-----+
                |             +-----------------+ 
                |
                |      
                |     CATIAStiDBChildren for Product Child Number 	CATIAStiDBItem 	Link
                |     Type
                |     Child n°1 	Reference Part 	Product Link
                |     Child n°2 	Contextual Part 	Product Link
                |
                |     CATIAStiDBChildren for Contextual Part Child Number 	CATIAStiDBItem 	Link
                |     Type
                |     Child n°1 	Reference Part 	Design Link
                |     Child n°2 	Product 	Contextual Link
                |
                |     CATIAStiDBChildren for Reference Part Child Number 	CATIAStiDBItem 	Link
                |     Type
                |
                |     Here is the List of all CATIA Link Types :
                |      
                |     CATIA Link Behavior 	Description
                |     CATIA Product Link 	Defines the basic Product Structure Link -i.e.: the
                |     link between either a Product and its Sub-Products or a Product and its
                |     Representation
                |     CATIA Design Link 	Defines Design Link -i.e.: Part to Part Link created
                |     with 'Copy/Paste ... with link' or as Contextual Link It can also be used for
                |     Link to external Parameters
                |     CATIA Design Table Link 	Defines the Link to a Design
                |     Table
                |     CATIA Rule Base Link 	Defines the Link to Document defining Rule
                |     Base
                |     CATIA Downstream Application Link 	Defines for instance the Link between a
                |     Drawing or an Analysis Document and a Part Document
                |     CATIA Contextual Link 	Defines the Link from a Part Document to its
                |     Context
                |     CATIA Result Link 	Defines the Link to "Result" document, like Analysis
                |     Reports, ...
                |     CATIA Is Composed Of Link 	Defines a simple "Composed Of" Link, like a
                |     Catalog Document Composed Of Sub-Catalog Documents
                |     CATIA Reference Link 	Defines any kind of Link that does not belong to one
                |     type described above including for instance OLE links, Link from a Catalog
                |     Document to a Part, Link to Material Document, ...
                |
                | See also:
                |     StiDBItem
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.sti_db_children = com_object

    @property
    def count(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Count() As long (Read Only)
                | 
                |     Returns the Number of Children currently gathered in
                |     CATIAStiDBChildren.
                | 
                |     Returns:
                |         This output corresponds to the Children Number of a CATIAStiDBItem.
                |         
                |     Example:
                | 
                |               This example retrieves in  lChildrenNumber the Number of children
                |               currently gathered in oStiDBChildren.
                |
                |          Dim oStiEngine As StiEngine
                |          Set oStiEngine = CATIA.GetItem("CAIEngine")
                |          Dim oStiDBItem As StiDBItem
                |          Set oStiDBItem = oStiEngine.GetStiDBItemFromCATBSTR("E:/CATIAFiles/Assembly.CATProduct")
                |          Dim oStiDBChildren As StiDBChildren
                |          Set oStiDBChildren = oStiDBItem.GetChildren()
                |          (...)
                |          Dim oNbChildren As long
                |          oNbChildren = oStiDBChildren.Count

        :return: int
        :rtype: int
        """

        return self.sti_db_children.Count

    def item(self, i_index: cat_variant) -> StiDBItem:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Item(CATVariant iIndex) As StiDBItem
                | 
                |     Returns the CATIAStiDBItem from its index in the
                |     CATIAStiDBChildren.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             This input corresponds to the Index of the CATIAStiDBItem to
                |             retrieve from the CATIAStiDBChildren. This index is the rank of the
                |             CATIAStiDBItem in the CATIAStiDBChildren -list of all the Children of a
                |             CATIAStiDBItem. The index of the first CATIAStiDBItem is '1' and the index of
                |             the last CATIAStiDBItem is 'Count'. 
                | 
                |     Returns:
                |         This ouptut corresponds to the retrieved CATIAStiDBItem from its index.
                |         
                |     Example:
                | 
                |           The following example returns in oChildStiDBItem the third
                |           CATIAStiDBItem
                |          gathered in oStiDBChildren.
                |
                |          Dim oStiEngine As StiEngine
                |          Set oStiEngine = CATIA.GetItem("CAIEngine")
                |          Dim oFatherStiDBItem As StiDBItem
                |          Set oFatherStiDBItem = oStiEngine.GetStiDBItemFromCATBSTR("E:\CATIAFiles\Assembly.CATProduct")
                |          Dim oStiDBChildren As StiDBChildren
                |          Set oStiDBChildren = oFatherStiDBItem.GetChildren()
                |          (...)
                |          Dim oStiDBItem As StiDBItem
                |          Set oStiDBItem = oStiDBChildren.Item(3)

        :param cat_variant i_index:
        :return: StiDBItem
        :rtype: StiDBItem
        """
        return StiDBItem(self.sti_db_children.Item(i_index))

    def link_type(self, i_index: cat_variant) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func LinkType(CATVariant iIndex) As CATBSTR
                | 
                |     Returns the Link Type from its index in the
                |     CATIAStiDBChildren.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             This input corresponds to the index of the Link Type to retrieve
                |             from the CATIAStiDBChildren. This index is the rank of the Link Type in the
                |             CATIAStiDBChildren. The index of the first Link Type is '1' and the index of
                |             the last Link Type is 'Count'. 
                | 
                |     Returns:
                |         This ouptut corresponds to the retrieved Link Type from its index.
                |         
                |     Example:
                | 
                |           The following example returns in oLinkType the third Link Type
                |           
                |          gathered in oStiDBChildren.
                |          
                | 
                |          Dim oStiEngine As StiEngine
                |          Set oStiEngine = CATIA.GetItem("CAIEngine")
                |          Dim oFatherStiDBItem As StiDBItem
                |          Set oFatherStiDBItem = oStiEngine.GetStiDBItemFromCATBSTR("E:/CATIAFiles/Assembly.CATProduct")
                |          Dim oStiDBChildren As StiDBChildren
                |          Set oStiDBChildren = oFatherStiDBItem.GetChildren()
                |          (...)
                |          Dim oLinkType As CATBSTR
                |          oLinkType = oStiDBChildren.LinkType(3)

        :param cat_variant i_index:
        :return: str
        :rtype: str
        """
        return self.sti_db_children.LinkType(i_index)

    def __repr__(self):
        return f'StiDBChildren(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.any_object import AnyObject


class AsySimActivity(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     AsySimActivity
                | 
                | Interface for a Delmia Simulation Activity.
                | Currently the main focus is to synchronize an activity with the simulation
                | world.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.asy_sim_activity = com_object

    def synchronize(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Synchronize()
                | 
                |     Updates the simulation world up to this activity.
                |     Role: Updates the simulation world (and its contents) to the end of the
                |     specified activity. Please note that no animation will occur, and the execution
                |     will wait for the simulation to finish before this method is complete.

        :return: None
        :rtype: None
        """
        return self.asy_sim_activity.Synchronize()

    def __repr__(self):
        return f'AsySimActivity(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.setting_controller import SettingController


class AnalysisPostProANRSettingAtt(SettingController):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     System.SettingController
                |                         AnalysisPostProANRSettingAtt
                | 
                | Interface to handle the Analysis & Simulation
                | "PostProcessingSetting".
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.analysis_post_pro_anr_setting_att = com_object

    @property
    def dmu_player_deformation(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property DMUPlayerDeformation() As long
                | 
                |     Returns or sets the DMUPlayerDeformation parameter.
                | 
                |     Parameters:
                | 
                |         iDMUPlayerDeformation
                |             Legal values:
                |             1 : Deformation is real
                |             2 : Deformation is amplified Ensure consistency with the C++ interface to which the work is delegated.

        :return: int
        :rtype: int
        """

        return self.analysis_post_pro_anr_setting_att.DMUPlayerDeformation

    @dmu_player_deformation.setter
    def dmu_player_deformation(self, value: int):
        """
        :param int value:
        """

        self.analysis_post_pro_anr_setting_att.DMUPlayerDeformation = value

    @property
    def dmu_player_mode(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property DMUPlayerMode() As long
                | 
                |     Returns or sets the DMUPlayerMode parameter.
                | 
                |     Parameters:
                | 
                |         iDMUPlayerMode
                |             Legal values:
                |             1 : Mode is One Occurrence
                |             2 : Mode is All Occurrences Ensure consistency with the C++ interface to which the work is delegated.

        :return: int
        :rtype: int
        """

        return self.analysis_post_pro_anr_setting_att.DMUPlayerMode

    @dmu_player_mode.setter
    def dmu_player_mode(self, value: int):
        """
        :param int value:
        """

        self.analysis_post_pro_anr_setting_att.DMUPlayerMode = value

    @property
    def dmu_player_steps_number(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property DMUPlayerStepsNumber() As long
                | 
                |     Returns or sets the DMUPlayerStepsNumber parameter. Ensure consistency with
                |     the C++ interface to which the work is delegated.

        :return: int
        :rtype: int
        """

        return self.analysis_post_pro_anr_setting_att.DMUPlayerStepsNumber

    @dmu_player_steps_number.setter
    def dmu_player_steps_number(self, value: int):
        """
        :param int value:
        """

        self.analysis_post_pro_anr_setting_att.DMUPlayerStepsNumber = value

    def get_dmu_player_deformation_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetDMUPlayerDeformationInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the DMUPlayerDeformation
                |     parameter.
                |     Role:Retrieves the state of the DMUPlayerDeformation parameter in the
                |     current environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :return: bool
        :rtype: bool
        """
        return self.analysis_post_pro_anr_setting_att.GetDMUPlayerDeformationInfo(io_admin_level, io_locked)

    def get_dmu_player_mode_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetDMUPlayerModeInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the DMUPlayerMode
                |     parameter.
                |     Role:Retrieves the state of the DMUPlayerMode parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :return: bool
        :rtype: bool
        """
        return self.analysis_post_pro_anr_setting_att.GetDMUPlayerModeInfo(io_admin_level, io_locked)

    def set_dmu_player_deformation_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetDMUPlayerDeformationLock(boolean iLocked)
                | 
                |     Locks or unlocks the DMUPlayerDeformation parameter.
                |     Role:Locks or unlocks the DMUPlayerDeformation parameter if it is possible
                |     in the current administrative context. In user mode this method will always
                |     return E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :return: None
        :rtype: None
        """
        return self.analysis_post_pro_anr_setting_att.SetDMUPlayerDeformationLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_dmu_player_deformation_lock'
        # # vba_code = """
        # # Public Function set_dmu_player_deformation_lock(analysis_post_pro_anr_setting_att)
        # #     Dim iLocked (2)
        # #     analysis_post_pro_anr_setting_att.SetDMUPlayerDeformationLock iLocked
        # #     set_dmu_player_deformation_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_dmu_player_mode_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetDMUPlayerModeLock(boolean iLocked)
                | 
                |     Locks or unlocks the DMUPlayerMode parameter.
                |     Role:Locks or unlocks the DMUPlayerMode parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :return: None
        :rtype: None
        """
        return self.analysis_post_pro_anr_setting_att.SetDMUPlayerModeLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_dmu_player_mode_lock'
        # # vba_code = """
        # # Public Function set_dmu_player_mode_lock(analysis_post_pro_anr_setting_att)
        # #     Dim iLocked (2)
        # #     analysis_post_pro_anr_setting_att.SetDMUPlayerModeLock iLocked
        # #     set_dmu_player_mode_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'AnalysisPostProANRSettingAtt(name="{self.name}")'
